PCB Environment: ResultCollection Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
ResultCollection Struct Reference

## Public Member Functions
bool | shouldAdd (const Action::Result &) const
void | add (ResultRecord &&)
void | reset ()
PyObject * | getPy () const

## Data Fields
std::vector< ResultRecord > | TimeLine
ResultRecord | WorstSuccess
ResultRecord | Worst
std::map< std::string, float > | F32
std::map< std::string, int64_t > | I64

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Stats.hpp